@@ -1,8 +1,9 @@
 #!/usr/bin/env python
+from __future__ import division
 ######################################################################
 #
 #   Module:  pyRijnadel
-#   Version: $Id: pyRijndael.py,v 1.3 2003/09/03 16:33:04 jsc Exp $
+#   Version: $Id: pyRijndael.py,v 1.4 2004/12/03 17:31:26 jsc Exp $
 #   Author:  Jeffrey Clement <jclement@bluesine.com>
 #   Targets: Win32, Unix
 #   Web:     http://jclement.ca/software/pyrijndael/
@@ -15,6 +16,9 @@
 # -------------------------------------------------------------------
 #
 # $Log: pyRijndael.py,v $
+# Revision 1.4  2004/12/03 17:31:26  jsc
+# *** empty log message ***
+#
 # Revision 1.3  2003/09/03 16:33:04  jsc
 # Fixed up licensing
 #
@@ -137,10 +141,10 @@ def RShiftL(lValue, iShiftBits):
     elif iShiftBits < 0 or iShiftBits > 31:
         raise "iShiftBits not in specified range!"
 
-    tmp = (lValue & 0x7FFFFFFE) / lutL2Power[iShiftBits]
+    tmp = (lValue & 0x7FFFFFFE) // lutL2Power[iShiftBits]
 
     if (lValue & minInt):
-        return (tmp | (0x40000000 / lutL2Power[iShiftBits-1]))
+        return (tmp | (0x40000000 // lutL2Power[iShiftBits-1]))
     else:
         return tmp
 
@@ -172,7 +176,7 @@ def RShiftB(bValue, iShiftBits):
             return 0
     elif iShiftBits < 0 or iShiftBits > 7:
         raise "iShiftBits not in specified range!"
-    return bValue / lutB2Power[iShiftBits]
+    return bValue // lutB2Power[iShiftBits]
 
 def RotateLeftL(lValue, iShiftBits):
     return LShiftL(lValue, iShiftBits) | RShiftL(lValue, (32-iShiftBits))
